Skip to contents

Implements the scale-invariant test of Cao et al. (2024) for high-dimensional linear hypotheses of \(k\)-sample mean vectors under heteroscedastic covariance structures.

Usage

CCXH2024.GLHTBF.2cNRT(Y, B, n, p, alpha = 0.05)

Arguments

Y

A list of \(k\) data matrices. The \(i\)th element represents the data matrix (\(n_i \times p\)) from the \(i\)th population with each row representing a \(p\)-dimensional observation.

B

A vector of \(k\) known scalars \((B_1,\ldots,B_k)\) specifying the linear combination of mean vectors.

n

A vector of \(k\) sample sizes. The \(i\)th element represents the sample size of group \(i\), \(n_i\).

p

The dimension of data.

alpha

Significance level used to report the critical value (default 0.05). P-value does not depend on alpha.

Value

A list of class "NRtest" containing the results of the hypothesis test.

Details

Suppose we have \(k\) independent high-dimensional samples $$\boldsymbol{Y}_{i1},\ldots,\boldsymbol{Y}_{in_i}\ \text{are i.i.d. with}\ \mathrm{E}(\boldsymbol{Y}_{i1})=\boldsymbol{\mu}_i,\ \mathrm{Cov}(\boldsymbol{Y}_{i1})=\boldsymbol{\Sigma}_i,\ i=1,\ldots,k,$$ where the covariance matrices \(\boldsymbol{\Sigma}_i\) may differ across groups.

It is of interest to test the k-sample linear hypothesis $$H_0:\ \sum_{i=1}^k B_i\boldsymbol{\mu}_i=\boldsymbol{0}\quad \text{vs.}\quad H_1:\ \sum_{i=1}^k B_i\boldsymbol{\mu}_i\neq\boldsymbol{0}.$$

Cao et al. (2024) proposed the following scale-invariant test statistic: $$T = p^{-1}\boldsymbol{Y}^{\top}\boldsymbol{D}_\sigma^{-1}\boldsymbol{Y},\quad \boldsymbol{Y}=\sqrt{n}\sum_{i=1}^k B_i\bar{\boldsymbol{Y}}_i,\quad n=\sum_{i=1}^k n_i,$$ where \(\bar{\boldsymbol{Y}}_i\) is the sample mean vector of group \(i\) and \(\boldsymbol{D}_\sigma\) is the diagonal matrix formed from a pooled covariance estimator. They showed that under the null hypothesis, \(T\) can be approximated by a Welch–Satterthwaite chi-square reference law \(\chi^2_{\nu^*}/\nu^*\), where \(\nu^*\) is an adjusted degrees-of-freedom parameter.

References

Cao M, Cheng Z, Xu K, He D (2024). “A scale-invariant test for linear hypothesis of means in high dimensions.” Statistical Papers, 65(6), 3477–3497.

Examples

# \donttest{
library("HDNRA")
data("corneal")

# corneal: 150 x p, split into 4 groups (n_i x p)
group1 <- as.matrix(corneal[1:43,  ])      # normal
group2 <- as.matrix(corneal[44:57, ])      # unilateral suspect
group3 <- as.matrix(corneal[58:78, ])      # suspect map
group4 <- as.matrix(corneal[79:150,])      # clinical keratoconus

Y <- list(group1, group2, group3, group4)
n <- c(nrow(group1), nrow(group2), nrow(group3), nrow(group4))
p <- ncol(group1)

# Example linear combination (single contrast)
B <- c(-2, 1, 2, -1)

CCXH2024.GLHTBF.2cNRT(Y, B, n, p, alpha = 0.05)
#> 
#> Results of Hypothesis Test
#> --------------------------
#> 
#> Test name:                       Cao et al. (2024)'s scale-invariant test
#> 
#> Null Hypothesis:                 Linear combination of mean vectors is 0
#> 
#> Alternative Hypothesis:          Linear combination of mean vectors is not 0
#> 
#> Data:                            Y
#> 
#> Sample Sizes:                    n1 = 43
#>                                  n2 = 14
#>                                  n3 = 21
#>                                  n4 = 72
#> 
#> Sample Dimension:                2000
#> 
#> Test Statistic:                  T[SI] = 2.5837
#> 
#> Approximation method to the      Welch-Satterthwaite chi-square approximation
#> null distribution of T[SI]: 
#> 
#> Approximation parameter(s):      nu_star  =       2.6143
#>                                  nu_hat   =       2.6636
#>                                  trR2_hat = 1501701.0103
#>                                  c_old    =      17.7895
#>                                  c_new    =       1.0189
#>                                  c_star   =       1.0189
#>                                  crit     =       2.7290
#> 
#> P-value:                         0.05965931
#> 
# }