Suppose we have two independent high-dimensional samples:
$$
\boldsymbol{y}_{i1},\ldots,\boldsymbol{y}_{in_i}, \;\operatorname{are \; i.i.d. \; with}\; \operatorname{E}(\boldsymbol{y}_{i1})=\boldsymbol{\mu}_i,\; \operatorname{Cov}(\boldsymbol{y}_{i1})=\boldsymbol{\Sigma}_i,i=1,2.
$$
The primary object is to test
$$H_{0}: \boldsymbol{\mu}_1 = \boldsymbol{\mu}_2\; \operatorname{versus}\; H_{1}: \boldsymbol{\mu}_1 \neq \boldsymbol{\mu}_2.$$
Srivastava et al. (2013) proposed the following test statistic:
$$T_{SKK} = \frac{(\bar{\boldsymbol{y}}_1 - \bar{\boldsymbol{y}}_2)^\top \hat{\boldsymbol{D}}^{-1}(\bar{\boldsymbol{y}}_1 - \bar{\boldsymbol{y}}_2) - p}{\sqrt{2 \widehat{\operatorname{Var}}(\hat{q}_n) c_{p,n}}},$$
where \(\bar{\boldsymbol{y}}_{i},i=1,2\) are the sample mean vectors, \(\hat{\boldsymbol{D}}=\hat{\boldsymbol{D}}_1/n_1+\hat{\boldsymbol{D}}_2/n_2\) with \(\hat{\boldsymbol{D}}_i,i=1,2\) being the diagonal matrices consisting of only the diagonal elements of the sample covariance matrices. \(\widehat{\operatorname{Var}}(\hat{q}_n)\) is given by equation (1.18) in Srivastava et al. (2013), and \(c_{p, n}\) is the adjustment coefficient proposed by Srivastava et al. (2013).
They showed that under the null hypothesis, \(T_{SKK}\) is asymptotically normally distributed.