F-approximation-based F-type test for GLHT problem under heteroscedasticity
Source:R/WZ2026.GLHTBF.2cNRT.R
WZ2026.GLHTBF.2cNRT.RdAn F-type normal reference test for the high-dimensional general linear hypothesis testing (GLHT) problem under heteroscedasticity. The null distribution is approximated by an F distribution using Welch–Satterthwaite (W–S) chi-square approximations.
Arguments
- Y
A list of \(k\) data matrices. The \(i\)th element represents the data matrix (\(n_i \times p\)) from the \(i\)th population with each row representing a \(p\)-dimensional observation.
- G
A known full-rank coefficient matrix (\(q \times k\)) with \(\operatorname{rank}(\boldsymbol{G}) < k\).
- n
A vector of \(k\) sample sizes. The \(i\)th element represents the sample size of group \(i\), \(n_i\).
- p
The dimension of data.
Details
The test statistic is of F-type form $$F_{n,p} = \frac{\|\boldsymbol{C\hat\mu}\|^2}{\operatorname{tr}(\widehat{\Omega}_n)}.$$ The degrees of freedom are estimated by matching the first two cumulants via W–S approximation, resulting in an \(F_{\hat d_1, \hat d_2}\) reference distribution.
References
Wang, P. and Zhu, T. (preprint). An F-type Test for Heteroscedastic General Linear Hypothesis Testing Problem for High Dimensional Data: a Normal Reference Approach.
Examples
library("HDNRA")
data("corneal")
dim(corneal)
#> [1] 150 2000
group1 <- as.matrix(corneal[1:43, ]) ## normal group
group2 <- as.matrix(corneal[44:57, ]) ## unilateral suspect group
group3 <- as.matrix(corneal[58:78, ]) ## suspect map group
group4 <- as.matrix(corneal[79:150, ]) ## clinical keratoconus group
p <- dim(corneal)[2]
Y <- list()
k <- 4
Y[[1]] <- group1
Y[[2]] <- group2
Y[[3]] <- group3
Y[[4]] <- group4
n <- c(nrow(Y[[1]]),nrow(Y[[2]]),nrow(Y[[3]]),nrow(Y[[4]]))
G <- cbind(diag(k-1),rep(-1,k-1))
WZ2026.GLHTBF.2cNRT(Y,G,n,p)
#>
#> Results of Hypothesis Test
#> --------------------------
#>
#> Test name: F-type normal reference test
#>
#> Null Hypothesis: The general linear hypothesis is true
#>
#> Alternative Hypothesis: The general linear hypothesis is not true
#>
#> Data: Y
#>
#> Sample Sizes: n1 = 43
#> n2 = 14
#> n3 = 21
#> n4 = 72
#>
#> Sample Dimension: 2000
#>
#> Test Statistic: F[WZ] = 4.1453
#>
#> Approximation method to the F-approximation (W-S chi^2 matching)
#> null distribution of F[WZ]:
#>
#> Approximation parameter(s): df1 = 6.1652
#> df2 = 118.4716
#> bias = 1.3010
#>
#> P-value: 0.0007252525
#>