Learn R Programming

HDNRA (version 2.0.1)

print.NRtest: Print Method for S3 Class "NRtest"

Description

Prints the details of the NRtest object in a user-friendly manner. This method provides a clear and concise presentation of the test results contained within the NRtest object, including all relevant statistical metrics and test details.

Usage

## S3 method for class \pkg{NRtest}
# S3 method for NRtest
print(x, ...)

Value

Invisibly returns the input x.

Arguments

x

an NRtest object.

...

further arguments passed to or from other methods.

Author

Pengfei Wang nie23.wp8738@e.ntu.edu.sg

Details

The print.NRtest function formats and presents the contents of the NRtest object, which includes statistical test results and related parameters. This function is designed to provide a user-friendly display of the object's contents, making it easier to understand the results of the analysis.

See Also

NRtest.object